@@ -11,7 +11,8 @@ class ezfuc(object):
 
     @staticmethod
     def retry(count=1):
-        """方法报错重试
+        """
+        方法报错重试
         """
 
         def dec(f):
@@ -278,7 +279,18 @@ class ezfuc(object):
         return rs
 
     @classmethod
-    def save_excel(self, resList, excel_name, title=""):
+    def make_dir(self, path):
+        """
+        创建目录
+        :param path:
+        :return:
+        """
+        import os
+        if not os.path.exists(path):
+            os.makedirs(path)
+
+    @classmethod
+    def save_excel(self, resList, excel_name, title=[], path=""):
         """
         将列表数据保存到表格
         :param excel_name:
@@ -286,7 +298,10 @@ class ezfuc(object):
         """
         import xlsxwriter
         from tqdm import tqdm
-        workbook = xlsxwriter.Workbook(f"{excel_name}.xlsx")
+        if path:
+            self.make_dir(path=path)
+            excel_name = path + excel_name
+        workbook = xlsxwriter.Workbook(excel_name)
         sheet = workbook.add_worksheet('Sheet1')  # 创建一个sheet表格
         if title:
             resList.insert(0, title)
@@ -399,4 +414,3 @@ class EmailSend(object):
 
     def send_video_email(self):
         pass
-
